
from rest_framework import serializers
from mpesaApp.models import mpesaDetail,payment



class DetailsSerializer(serializers.ModelSerializer):

    class Meta:
        model = mpesaDetail
        fields = ('BusinessShortCode', 'Password', 'Timestamp','TransactionType',
        'PartyA','PartyB','CallBackURL','AccountReference','TransactionDesc')

        # read_only_fields = ('BusinessShortCode', 'Password', 'Timestamp','TransactionType',
        # 'PartyA','PartyB','CallBackURL','AccountReference','TransactionDesc')


class PaymentSerializer(serializers.ModelSerializer):
    """ A class to serialize payment as json compatible data """

    class Meta:
        model = payment

        fields = ('title', 'amount','phone',)



import ast
import json
import pprint

import requests
from django.http import HttpResponse
from requests.auth import HTTPBasicAuth

from mpesaApp.api import DetailsSerializer
from mpesaApp.models import mpesaDetail
from .api import PaymentSerializer
from rest_framework import generics
from .models import payment
from rest_framework.response import Response
from rest_framework import status



class PayrollListView(generics.ListCreateAPIView):
    queryset = payment.objects.all()
    serializer_class = PaymentSerializer

    def get(self, request, *args, **kwargs):
        return self.list(request, *args, **kwargs)

    def create(self, request, *args, **kwargs):
        details = mpesaDetail.objects.all()
        serializer1 = self.get_serializer(data=request.data)

        serializer1.is_valid(raise_exception=True)
        serializer1.validated_data
        
        print(serializer1.is_valid())


        amount1 = serializer1.validated_data['amount']
        phone = serializer1.validated_data['phone']

        data = request.POST.dict()
        title = str(data.get("amount"))

        price = str(data.get("amount"))
        number = str("254" + data.get("phone")[1:])

        print(amount1, phone)

        print('*******  Stk payload here  *************')
        print(details)

        serializer = DetailsSerializer(details, many=True)

        parameter = json.dumps(serializer.data[0])

        numbber_amount = json.dumps({"Amount": price, "PhoneNumber": number})

        jsonMerged = {**json.loads(parameter), **json.loads(numbber_amount)}

        payload = json.dumps(jsonMerged, indent=4)

        print(payload)

        for val in details:
            consumer_key = val.consumer_key

            consumer_secret = val.CONSUMER_SECRET

            token_api_URL = val.GENERATE_TOKEN_URL

            r = requests.get(token_api_URL, auth=HTTPBasicAuth(consumer_key, consumer_secret))

            access_token = r.json()['access_token']

            print('access_token-->>>>> {0}'.format(access_token))

            api_url = str(val.api_url)
            headers = {"Authorization": "Bearer %s" % access_token}

            params = ast.literal_eval(payload)

            response = requests.post(api_url, json=params, headers=headers)

            pprint.pprint(response)

            print("Params:{0} ".format(params))

        serializer1.save()

        return Response({'message': 'Payment Processed Successfully'}, status=status.HTTP_200_OK)




import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# Allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name = 'DjangoMpesa',
    version = '1.3',
    packages = ['mpesaApp'],
    include_package_data = True,
    license = 'BSD License',
    description = 'A simple Django app for integrating mpesa stk push payment to your django site.',
    long_description = README,
    url = 'http://www.techtenant.co.ke/',
    author = 'Oronz',
    keywords = ['MPESA', 'Django', 'Djangompesa'],   # Keywords that define your package best

    author_email = 'brianoroni6@gmail.com',
    classifiers =[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.8',
    ],
    python_requires= '>=3.8',

)



from django.db import models

# Create your models here.


class mpesaDetail(models.Model):
    api_url = models.CharField(max_length=255)
    BusinessShortCode = models.CharField(max_length=255)
    Password = models.CharField(max_length=255)
    Timestamp = models.CharField(max_length=255)
    TransactionType = models.CharField(max_length=255)
    PartyA = models.CharField(max_length=255)
    PartyB = models.CharField(max_length=255)
    CallBackURL = models.CharField(max_length=255)
    AccountReference = models.CharField(max_length=255)
    TransactionDesc = models.CharField(max_length=255)

    consumer_key = models.CharField(max_length=255)
    CONSUMER_SECRET = models.CharField(max_length=255)
    GENERATE_TOKEN_URL = models.CharField(max_length=255)

    def __str__(self):
        return self.BusinessShortCode

class payment(models.Model):
    created = models.DateTimeField(auto_now_add=True)
    title = models.CharField(max_length=100, blank=True, default='')
    amount = models.IntegerField()
    phone=models.CharField(max_length=100)
   

    class Meta:
        ordering = ('created',)
    
    def __str__(self):
        return self.title